Index: pkg/analyzer/lib/src/dart/element/element.dart |
diff --git a/pkg/analyzer/lib/src/dart/element/element.dart b/pkg/analyzer/lib/src/dart/element/element.dart |
index 70299ad3fdc737f0f433d510f4719fac17f3ea64..3ec4819e6e27a7f9beae459598bba035ea25cd56 100644 |
--- a/pkg/analyzer/lib/src/dart/element/element.dart |
+++ b/pkg/analyzer/lib/src/dart/element/element.dart |
@@ -2336,7 +2336,7 @@ abstract class ConstVariableElement |
* If this element is resynthesized from the summary, return the unlinked |
* initializer, otherwise return `null`. |
*/ |
- UnlinkedConst get _unlinkedConst; |
+ UnlinkedExpr get _unlinkedConst; |
/** |
* Return a representation of the value of this variable, forcing the value |
@@ -3129,7 +3129,7 @@ abstract class ElementImpl implements Element { |
* Return annotations for the given [unlinkedConsts] in the [unit]. |
*/ |
List<ElementAnnotation> _buildAnnotations( |
- CompilationUnitElementImpl unit, List<UnlinkedConst> unlinkedConsts) { |
+ CompilationUnitElementImpl unit, List<UnlinkedExpr> unlinkedConsts) { |
int length = unlinkedConsts.length; |
if (length != 0) { |
List<ElementAnnotation> annotations = new List<ElementAnnotation>(length); |
@@ -6811,7 +6811,7 @@ abstract class NonParameterVariableElementImpl extends VariableElementImpl { |
/** |
* Subclasses need this getter, see [ConstVariableElement._unlinkedConst]. |
*/ |
- UnlinkedConst get _unlinkedConst => _unlinkedVariable?.initializer?.bodyExpr; |
+ UnlinkedExpr get _unlinkedConst => _unlinkedVariable?.initializer?.bodyExpr; |
} |
/** |
@@ -7178,7 +7178,7 @@ class ParameterElementImpl extends VariableElementImpl |
/** |
* Subclasses need this getter, see [ConstVariableElement._unlinkedConst]. |
*/ |
- UnlinkedConst get _unlinkedConst => _unlinkedParam?.initializer?.bodyExpr; |
+ UnlinkedExpr get _unlinkedConst => _unlinkedParam?.initializer?.bodyExpr; |
@override |
accept(ElementVisitor visitor) => visitor.visitParameterElement(this); |
@@ -7760,14 +7760,14 @@ abstract class PropertyInducingElementImpl |
*/ |
abstract class ResynthesizerContext { |
/** |
* Build [ElementAnnotationImpl] for the given [UnlinkedConst]. |
*/ |
- ElementAnnotationImpl buildAnnotation(ElementImpl context, UnlinkedConst uc); |
+ ElementAnnotationImpl buildAnnotation(ElementImpl context, UnlinkedExpr uc); |
/** |
* Build [Expression] for the given [UnlinkedConst]. |
*/ |
- Expression buildExpression(ElementImpl context, UnlinkedConst uc); |
+ Expression buildExpression(ElementImpl context, UnlinkedExpr uc); |
/** |
* Build explicit top-level property accessors. |
@@ -7760,14 +7760,14 @@ abstract class PropertyInducingElementImpl |
abstract class ResynthesizerContext { |
/** |
- * Build [ElementAnnotationImpl] for the given [UnlinkedConst]. |
+ * Build [ElementAnnotationImpl] for the given [UnlinkedExpr]. |
*/ |
@@ -7760,14 +7760,14 @@ abstract class PropertyInducingElementImpl |
/** |
- * Build [Expression] for the given [UnlinkedConst]. |
+ * Build [Expression] for the given [UnlinkedExpr]. |
*/ |